@@ -29,14 +29,13 @@
 
 #include "panel-action-button.h"
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "applet.h"
 #include "menu.h"
 #include "panel-config-global.h"
 #include "panel-gconf.h"
 #include "panel-profile.h"
-#include "panel-stock-icons.h"
 #include "panel-typebuiltins.h"
 #include "panel-force-quit.h"
 #include "panel-util.h"
@@ -66,18 +65,19 @@ struct _PanelActionButtonPrivate {
 static GObjectClass *parent_class;
 
 static GConfEnumStringPair panel_action_type_map [] = {
-	{ PANEL_ACTION_NONE,         "none"         },
-	{ PANEL_ACTION_LOCK,         "lock"         },
-	{ PANEL_ACTION_LOGOUT,       "logout"       },
-	{ PANEL_ACTION_RUN,          "run"          },
-	{ PANEL_ACTION_SEARCH,       "search"       },
-	{ PANEL_ACTION_SCREENSHOT,   "screenshot"   },
-	{ PANEL_ACTION_FORCE_QUIT,   "force-quit"   },
+	{ PANEL_ACTION_NONE,           "none"           },
+	{ PANEL_ACTION_LOCK,           "lock"           },
+	{ PANEL_ACTION_LOGOUT,         "logout"         },
+	{ PANEL_ACTION_RUN,            "run"            },
+	{ PANEL_ACTION_SEARCH,         "search"         },
+	{ PANEL_ACTION_SCREENSHOT,     "screenshot"     },
+	{ PANEL_ACTION_FORCE_QUIT,     "force-quit"     },
+	{ PANEL_ACTION_CONNECT_SERVER, "connect-server" }
 };
 
 /* Lock Screen
  */
-void
+static void
 panel_action_lock_screen (GtkWidget *widget)
 {
 	panel_lock_screen (gtk_widget_get_screen (widget));
@@ -159,7 +159,7 @@ panel_action_lock_invoke_menu (PanelActionButton *button,
 
 /* Log Out
  */
-void
+static void
 panel_action_logout (GtkWidget *widget)
 {
 	static int recursion_guard = 0;
@@ -176,7 +176,7 @@ panel_action_logout (GtkWidget *widget)
 
 /* Run Application
  */
-void
+static void
 panel_action_run_program (GtkWidget *widget)
 {
 	panel_run_dialog_present (gtk_widget_get_screen (widget), gtk_get_current_event_time ());
@@ -184,20 +184,41 @@ panel_action_run_program (GtkWidget *widget)
 
 /* Search For Files
  */
-void
+static void
 panel_action_search (GtkWidget *widget)
 {
+	GnomeDesktopItem *ditem;
 	GdkScreen *screen;
 	GError    *error = NULL;
 	char      *argv[2] = {"gnome-search-tool", NULL};
+	char      *file;
 
 	screen = gtk_widget_get_screen (widget);
+	file = panel_lookup_in_data_dirs ("applications/gnome-search-tool.desktop");
 
-	if (!gdk_spawn_on_screen (screen, NULL, argv, NULL,
+	if (file) {
+		ditem = gnome_desktop_item_new_from_file (file, 0, &error);
+		if (ditem) {
+			g_assert (error == NULL);	
+			panel_ditem_launch (ditem, NULL, 0, screen, &error);
+			gnome_desktop_item_unref (ditem);
+		}
+		if (error) {
+			panel_error_dialog (screen,
+			                    "cannot_exec_gnome-search-tool", TRUE,
+			                    _("Cannot execute '%s'"),
+			                    "%s",
+			                    "gnome-search-tool",
+			                    error->message);
+			g_error_free (error);
+		}
+		g_free (file);
+	}
+	else if (!gdk_spawn_on_screen (screen, NULL, argv, NULL,
 				  G_SPAWN_SEARCH_PATH,
 				  NULL, NULL, NULL, &error)) {
 		panel_error_dialog (screen,
-				    "cannot_exec_gnome-search-tool",
+				    "cannot_exec_gnome-search-tool", TRUE,
 				    _("Cannot execute '%s'"),
 				    "%s",
 				    "gnome-search-tool",
@@ -208,12 +229,12 @@ panel_action_search (GtkWidget *widget)
 
 /* Take Screenshot
  */
-void
+static void
 panel_action_screenshot (GtkWidget *widget)
 {
 	GdkScreen *screen;
 	GError    *error = NULL;
-	char      *argv [2] = {"gnome-panel-screenshot", NULL};
+	char      *argv [2] = {"gnome-screenshot", NULL};
 
 	screen = gtk_widget_get_screen (widget);
 
@@ -221,10 +242,10 @@ panel_action_screenshot (GtkWidget *widget)
 				  G_SPAWN_SEARCH_PATH,
 				  NULL, NULL, NULL, &error)) {
 		panel_error_dialog (screen,
-				    "cannot_exec_gnome-panel-screenshot",
+				    "cannot_exec_gnome-screenshot", TRUE,
 				    _("Cannot execute '%s'"),
 				    "%s",
-				    "gnome-panel-screenshot",
+				    "gnome-screenshot",
 				    error->message);
 		g_error_free (error);
 	}
@@ -238,9 +259,35 @@ panel_action_force_quit (GtkWidget *widget)
 	panel_force_quit (gtk_widget_get_screen (widget));
 }
 
+/* Connect Server
+ */
+static void
+panel_action_connect_server (GtkWidget *widget)
+{
+	GdkScreen *screen;
+	GError    *error;
+	
+	screen = gtk_widget_get_screen (GTK_WIDGET (widget));
+	error = NULL;
+
+	gdk_spawn_command_line_on_screen (screen, "nautilus-connect-server",
+					  &error);
+
+	if (error) {
+		GtkWidget *error_dialog;
+
+		error_dialog = panel_error_dialog (screen,
+						   "cannot_connect_server",
+						   TRUE,
+						   _("Cannot connect to server"),
+						   "%s", error->message);
+		g_clear_error (&error);
+	}
+}
+
 typedef struct {
 	PanelActionButtonType   type;
-	char                   *stock_icon;
+	char                   *icon_name;
 	char                   *text;
 	char                   *tooltip;
 	char                   *help_index;
@@ -257,13 +304,13 @@ typedef struct {
 static PanelAction actions [] = {
 	{
 		PANEL_ACTION_NONE,
-		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL, NULL,
 		NULL, NULL, NULL, NULL
 	},
 	{
 		PANEL_ACTION_LOCK,
-		PANEL_STOCK_LOCKSCREEN,
-		N_("Lock screen"),
+		"gnome-lockscreen",
+		N_("Lock Screen"),
 		N_("Protect your computer from unauthorized use"),
 		"gospanel-21",
 		"ACTION:lock:NEW",
@@ -274,7 +321,7 @@ static PanelAction actions [] = {
 	},
 	{
 		PANEL_ACTION_LOGOUT,
-		PANEL_STOCK_LOGOUT,
+		"gnome-logout",
 		N_("Log Out"),
 		N_("Log out of this session to log in as a different user or to shut down the computer"),
 		"gospanel-20",
@@ -284,7 +331,7 @@ static PanelAction actions [] = {
 	},
 	{
 		PANEL_ACTION_RUN,
-		PANEL_STOCK_RUN,
+		PANEL_RUN_ICON,
 		N_("Run Application..."),
 		N_("Run an Application by entering a command"),
 		"gospanel-555",
@@ -294,7 +341,7 @@ static PanelAction actions [] = {
 	},
 	{
 		PANEL_ACTION_SEARCH,
-		PANEL_STOCK_SEARCHTOOL,
+		"gnome-searchtool",
 		N_("Search for Files..."),
 		N_("Find files, folders, and documents on your computer"),
 		"gospanel-554",
@@ -303,7 +350,7 @@ static PanelAction actions [] = {
 	},
 	{
 		PANEL_ACTION_SCREENSHOT,
-		PANEL_STOCK_SCREENSHOT,
+		"applets-screenshooter",
 		N_("Take Screenshot..."),
 		N_("Take a screenshot of your desktop"),
 		"gospanel-553",
@@ -312,13 +359,22 @@ static PanelAction actions [] = {
 	},
 	{
 		PANEL_ACTION_FORCE_QUIT,
-		PANEL_STOCK_FORCE_QUIT,
+		PANEL_FORCE_QUIT_ICON,
 		N_("Force Quit"),
 		N_("Force a misbehaving application to quit"),
 		"gospanel-563",
 		"ACTION:force-quit:NEW",
 		panel_action_force_quit, NULL, NULL,
 		panel_lockdown_get_disable_force_quit
+	},
+	{
+		PANEL_ACTION_CONNECT_SERVER,
+		"gnome-globe", //FIXME icon
+		N_("Connect to Server..."),
+		N_("Connect to a remote server"), //FIXME
+		"gospanel-563", //FIXME
+		"ACTION:connect-server:NEW",
+		panel_action_connect_server, NULL, NULL, NULL
 	}
 };
 
@@ -333,12 +389,22 @@ panel_action_get_is_disabled (PanelActionButtonType type)
 	return FALSE;
 }
 
-G_CONST_RETURN char*
-panel_action_get_stock_icon (PanelActionButtonType type)
+GCallback
+panel_action_get_invoke (PanelActionButtonType type)
 {
 	g_return_val_if_fail (type > PANEL_ACTION_NONE && type < PANEL_ACTION_LAST, NULL);
 
-	return actions[type].stock_icon;
+	g_assert (actions[type].invoke != NULL);
+
+	return G_CALLBACK (actions[type].invoke);
+}
+
+G_CONST_RETURN char*
+panel_action_get_icon_name (PanelActionButtonType type)
+{
+	g_return_val_if_fail (type > PANEL_ACTION_NONE && type < PANEL_ACTION_LAST, NULL);
+
+	return actions[type].icon_name;
 }
 
 G_CONST_RETURN char*
@@ -582,7 +648,8 @@ panel_action_button_set_type (PanelActionButton     *button,
 
 	button->priv->type = type;
 
-	button_widget_set_stock_id (BUTTON_WIDGET (button), actions [type].stock_icon);
+	if (actions [type].icon_name != NULL)
+		button_widget_set_icon_name (BUTTON_WIDGET (button), actions [type].icon_name);
 
 	gtk_tooltips_set_tip (panel_tooltips, GTK_WIDGET (button),
 			      _(actions [type].tooltip), NULL);
@@ -616,13 +683,10 @@ panel_action_button_type_changed (GConfClient       *client,
 static void
 panel_action_button_connect_to_gconf (PanelActionButton *button)
 {
-	const char  *key;
-	const char  *profile;
-
-	profile = panel_profile_get_name ();
+	const char *key;
 
 	key = panel_gconf_full_key (
-			PANEL_GCONF_OBJECTS, profile, button->priv->info->id, "action_type");
+			PANEL_GCONF_OBJECTS, button->priv->info->id, "action_type");
 
 	button->priv->gconf_notify =
 		gconf_client_notify_add (panel_gconf_get_client (), key, 
@@ -636,7 +700,8 @@ panel_action_button_connect_to_gconf (PanelActionButton *button)
 static void
 panel_action_button_style_set (PanelActionButton *button)
 {
-	button_widget_set_stock_id (BUTTON_WIDGET (button), actions [button->priv->type].stock_icon);
+	if (actions [button->priv->type].icon_name != NULL)
+		button_widget_set_icon_name (BUTTON_WIDGET (button), actions [button->priv->type].icon_name);
 }
 
 static void
@@ -696,16 +761,14 @@ panel_action_button_create (PanelToplevel         *toplevel,
 			    PanelActionButtonType  type)
 {
 	GConfClient *client;
-	const char  *profile;
 	const char  *key;
 	char        *id;
 
 	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
 
 	id = panel_profile_prepare_object (PANEL_OBJECT_ACTION, toplevel, position, FALSE);
 
-	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "action_type");
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id, "action_type");
 	gconf_client_set_string (client,
 				 key,
 				 gconf_enum_to_string (panel_action_type_map, type),
@@ -747,12 +810,9 @@ panel_action_button_load_from_gconf (PanelWidget *panel,
 {
 	int          type;
 	const char  *key;
-	const char  *profile;
 	char        *action_type;
 
-	profile = panel_profile_get_name ();
-
-	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "action_type");
+	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, id, "action_type");
 	action_type = gconf_client_get_string (panel_gconf_get_client (), key, NULL);
 
 	if (!gconf_string_to_enum (panel_action_type_map, action_type, &type)) {
@@ -857,8 +917,11 @@ panel_action_button_set_dnd_enabled (PanelActionButton *button,
 		gtk_drag_source_set (GTK_WIDGET (button), GDK_BUTTON1_MASK,
 				     dnd_targets, 1,
 				     GDK_ACTION_COPY | GDK_ACTION_MOVE);
-		gtk_drag_source_set_icon_stock (GTK_WIDGET (button),
-						actions [button->priv->type].stock_icon);
+		/* FIXME: waiting for bug #116577
+		if (actions [button->priv->type].icon_name != NULL)
+		gtk_drag_source_set_icon_name (GTK_WIDGET (button),
+						actions [button->priv->type].icon_name);
+						*/
 		GTK_WIDGET_SET_FLAGS (button, GTK_NO_WINDOW);
 	} else
 		gtk_drag_source_unset (GTK_WIDGET (button));
