@@ -480,7 +480,7 @@ drop_url (PanelWidget *panel,
 
 	panel_launcher_create_from_info (panel->toplevel, position, FALSE,
 					 netscape_url[NETSCAPE_URL_URL],
-					 name, comment, "gnome-globe.png");
+					 name, comment, "gnome-globe");
 
 	g_free (comment);
 	g_strfreev (netscape_url);
@@ -491,18 +491,19 @@ drop_url (PanelWidget *panel,
 static gboolean
 drop_menu (PanelWidget *panel,
 	   int          position,
+	   const char  *menu_filename,
 	   const char  *menu_path)
 {
 	if (!panel_profile_id_lists_are_writable ())
 		return FALSE;
 
-	panel_menu_button_create (panel->toplevel,
-				  position,
-				  menu_path,
-				  menu_path != NULL,
-				  NULL);
+	return panel_menu_button_create (panel->toplevel,
+					 position,
+					 menu_filename,
+					 menu_path,
+					 menu_path != NULL,
+					 NULL);
 
-	return TRUE;
 }
 
 static gboolean
@@ -605,14 +606,14 @@ drop_urilist (PanelWidget *panel,
 			} else {
 				char *icon;
 
-				icon = gnome_icon_lookup (panel_icon_theme,
+				icon = gnome_icon_lookup (gtk_icon_theme_get_default (),
 							  NULL, NULL, NULL,
 							  info, info->mime_type,
 							  GNOME_ICON_LOOKUP_FLAGS_NONE,
 							  NULL);
 
 				if (!icon)
-					icon = g_strdup ("gnome-unknown.png");
+					icon = g_strdup ("gnome-unknown");
 
 				if (!drop_uri (panel, pos, uri, icon))
 					success = FALSE;
@@ -620,7 +621,7 @@ drop_urilist (PanelWidget *panel,
 				g_free (icon);
 			}
 		} else {
-			if (!drop_uri (panel, pos, uri, "gnome-unknown.png"))
+			if (!drop_uri (panel, pos, uri, "gnome-unknown"))
 				success = FALSE;
 		}
 
@@ -718,12 +719,27 @@ drop_internal_applet (PanelWidget *panel, int pos, const char *applet_type,
 			g_warning ("Only MOVE supported for menus/drawers");
 		success = move_applet (panel, pos, applet_index);
 
-	} else if (strncmp (applet_type, "MENU:", strlen("MENU:")) == 0) {
-		const char *menu = &applet_type[strlen ("MENU:")];
-		if (strcmp (menu, "MAIN") == 0)
-			success = drop_menu (panel, pos, NULL);
-		else
-			success = drop_menu (panel, pos, menu);
+	} else if (strncmp (applet_type, "MENU:", strlen ("MENU:")) == 0) {
+		const char *menu;
+		const char *menu_path;
+
+		menu = &applet_type[strlen ("MENU:")];
+		menu_path = strchr (menu, '/');
+
+		if (!menu_path) {
+			if (strncmp (menu, "MAIN", strlen ("MAIN")) == 0)
+				success = drop_menu (panel, pos, NULL, NULL);
+			else
+				success = drop_menu (panel, pos, menu, NULL);
+		} else {
+			char *menu_filename;
+
+			menu_filename = g_strndup (menu, menu_path - menu);
+			*menu_path++;
+			success = drop_menu (panel, pos,
+					     menu_filename, menu_path);
+			g_free (menu_filename);
+		}
 
 	} else if (!strcmp (applet_type, "DRAWER:NEW")) {
 		if (panel_profile_id_lists_are_writable ()) {
@@ -1009,7 +1025,8 @@ panel_receive_dnd_data (PanelWidget      *panel,
 		}
 		break;
 	case TARGET_DIRECTORY:
-		success = drop_uri (panel, pos, (char *)selection_data->data, "gnome-fs-directory.png");
+		success = drop_uri (panel, pos, (char *)selection_data->data,
+				    "gnome-fs-directory");
 		break;
 	case TARGET_APPLET:
 		if (!selection_data->data) {
